@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.1.1'
+__version__   = '2.1.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2021-May-31'   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.1.1.html'
+__date__      = '2021-June-13'   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.1.2.html'
 __copyright__ = "(C) 2021 Avinash Kak. Python Software Foundation."
 
 
